pub struct Scalar(/* private fields */);arithmetic only.Expand description
Scalars are elements in the finite field modulo n.
Trait impls
Much of the important functionality of scalars is provided by traits from
the ff crate, which is re-exported as
p521::elliptic_curve::ff:
Field- represents elements of finite fields and provides:Field::random- generate a random scalardouble,square, andinvertoperations- Bounds for
Add,Sub,Mul, andNeg(as well as*Assignequivalents) - Bounds for
ConditionallySelectablefrom thesubtlecrate
PrimeField- represents elements of prime fields and provides:from_repr/to_reprfor converting field elements from/to big integers.multiplicative_generatorandroot_of_unityconstants.
PrimeFieldBits- operations over field elements represented as bits (requiresbitsfeature)
Please see the documentation for the relevant traits for more information.
Implementations
Sourceimpl Scalar
impl Scalar
Sourcepub fn from_bytes(repr: &FieldBytes) -> CtOption<Self>
pub fn from_bytes(repr: &FieldBytes) -> CtOption<Self>
Create a Scalar from a canonical big-endian representation.
Sourcepub fn from_slice(slice: &[u8]) -> Result<Self>
pub fn from_slice(slice: &[u8]) -> Result<Self>
Decode Scalar from a big endian byte slice.
Sourcepub fn to_bytes(self) -> FieldBytes
pub fn to_bytes(self) -> FieldBytes
Returns the big-endian encoding of this Scalar.
Sourcepub const fn to_canonical(self) -> Uint
Available on 64-bit only.
pub const fn to_canonical(self) -> Uint
Sourcepub const fn pow_vartime<const RHS_LIMBS: usize>(
&self,
exp: &Uint<RHS_LIMBS>,
) -> Self
pub const fn pow_vartime<const RHS_LIMBS: usize>( &self, exp: &Uint<RHS_LIMBS>, ) -> Self
Returns self^exp, where exp is a little-endian integer exponent.
This operation is variable time with respect to the exponent exp.
If the exponent is fixed, this operation is constant time.
Sourcepub const fn sqn_vartime(&self, n: usize) -> Self
pub const fn sqn_vartime(&self, n: usize) -> Self
Returns self^(2^n) mod p.
This operation is variable time with respect to the exponent n.
If the exponent is fixed, this operation is constant time.